summaryrefslogtreecommitdiff
path: root/src/mongo/shell/utils.js
diff options
context:
space:
mode:
Diffstat (limited to 'src/mongo/shell/utils.js')
-rw-r--r--src/mongo/shell/utils.js12
1 files changed, 7 insertions, 5 deletions
diff --git a/src/mongo/shell/utils.js b/src/mongo/shell/utils.js
index 33689f5f8b9..c3377a1254e 100644
--- a/src/mongo/shell/utils.js
+++ b/src/mongo/shell/utils.js
@@ -337,12 +337,14 @@ jsTestOptions = function() {
TestData.setSkipShardingPartsOfPrepareTransactionFailpoint || false,
roleGraphInvalidationIsFatal: TestData.roleGraphInvalidationIsFatal || false,
networkErrorAndTxnOverrideConfig: TestData.networkErrorAndTxnOverrideConfig || {},
// When randomBinVersions is true, randomly assign the binary versions of each node
// in the replica set to 'latest' or 'last-stable'.
// This flag is currently a placeholder and only sets the replica set to last-stable
- // FCV. Randomized behavior will be implemented as part of SERVER-42774.
- randomBinVersions: TestData.randomBinVersions || false,
- // Set a specific random seed to be used when randomBinVersions is true.
+ // FCV.
+ useRandomBinVersionsWithinReplicaSet:
+ TestData.useRandomBinVersionsWithinReplicaSet || false,
+ // Set a specific random seed to be used when useRandomBinVersionsWithinReplicaSet is
+ // true.
seed: TestData.seed || undefined,
});
}
@@ -337,12 +337,14 @@ jsTestOptions = function() {
roleGraphInvalidationIsFatal: TestData.roleGraphInvalidationIsFatal || false,
networkErrorAndTxnOverrideConfig: TestData.networkErrorAndTxnOverrideConfig || {},
- // When randomBinVersions is true, randomly assign the binary versions of each node
- // in the replica set to 'latest' or 'last-stable'.
+ // When useRandomBinVersionsWithinReplicaSet is true, randomly assign the binary
+ // versions of each node in the replica set to 'latest' or 'last-stable'.
// This flag is currently a placeholder and only sets the replica set to last-stable